(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     90606,       1856]
NotebookOptionsPosition[     85254,       1765]
NotebookOutlinePosition[     85747,       1783]
CellTagsIndexPosition[     85704,       1780]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 8, Section 8.15, Figure 8.29b", "Section",ExpressionUUID->"c86ab8d0-f2e0-430f-9eba-c802d258ac8b"],

Cell["\<\
First we input the masses (in kg) of the uranian satellites Miranda, Ariel \
and Umbriel using the data from Table A.11.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5ef0332b-04a8-4df1-9519-392471bcc80c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mass", " ", "=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.659", ",", " ", "13.53", ",", "11.72"}], "}"}], "*", 
   RowBox[{"10", "^", 
    RowBox[{"(", "20", ")"}]}]}]}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"9cd32df4-35a3-4f90-82ef-3c9bd9cbf0cf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6.59`*^19", ",", "1.353`*^21", ",", "1.172`*^21"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.811584731085238*^9, 3.811584774884386*^9},
 CellLabel->"Out[1]=",ExpressionUUID->"39b54702-10fc-45a3-aac8-cfeedec13a18"]
}, Open  ]],

Cell["\<\
Then we input their current semi-major axes again using data from Table A.11.\
\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"06f74281-b329-47ba-9944-1f17de509e22"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ao", "=", 
  RowBox[{"{", 
   RowBox[{"129800", ",", " ", "191200", ",", "266000"}], "}"}]}]], "Input",
 CellLabel->"In[2]:=",ExpressionUUID->"dc874c31-e029-4d71-ac34-d1e4554bc82d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"129800", ",", "191200", ",", "266000"}], "}"}]], "Output",
 CellChangeTimes->{3.8115847312094193`*^9, 3.81158477498536*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"9459b40b-1a4f-4610-8135-b9c3c6513e5f"]
}, Open  ]],

Cell[TextData[{
 "Defiine a function ",
 StyleBox["compare", "Input"],
 " that calculates the ratio given in Eq.(8.251).  If this ratio is greater \
than 1 then the pair of satellites is approaching one another; if it is less \
than 1 then they are receding from one another.."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"eee9ea91-17bd-4986-ae7f-296106f08e33"],

Cell[BoxData[
 RowBox[{
  RowBox[{"compare", "[", 
   RowBox[{"i_", ",", " ", "j_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"mass", "[", 
      RowBox[{"[", "i", "]"}], "]"}], "/", 
     RowBox[{"mass", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], ")"}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ao", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "/", 
      RowBox[{"ao", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"11", "/", "2"}], ")"}]}]}]}]], "Input",
 CellLabel->"In[3]:=",ExpressionUUID->"ebc077b4-c741-4487-af41-8394963c72c0"],

Cell["\<\
Calculate and display the values of compare for all possible pairs of \
satellites.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"291108fe-4c8a-4f81-8756-076b6841fdf1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"compare", "[", 
     RowBox[{"i", ",", "j"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"49a8c7e5-7d98-4582-b4fd-8dda33d4545f"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1.`", "0.40997766074659453`", "2.909350167725134`"},
     {"2.439157290128781`", "1.`", "7.096362671144149`"},
     {"0.34371936767649924`", "0.14091726231330978`", "1.`"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.8115847312194757`*^9, 3.811584775070486*^9},
 CellLabel->
  "Out[4]//MatrixForm=",ExpressionUUID->"add7ea5d-f370-4e1d-bff6-\
767b30866502"]
}, Open  ]],

Cell[TextData[{
 "Define a function ",
 StyleBox["a", "Input"],
 " that returns the semi-major axis of satellite ",
 StyleBox["i", "Input"],
 " at time ",
 StyleBox["t", "Input"],
 ".  This is derived from Eq.(8.252) with ",
 StyleBox["K",
  FontSlant->"Italic"],
 " = 0.5."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"aa48dd1d-92d3-42f7-84b0-3ac9f01df4df"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "[", 
   RowBox[{"i_", ",", "t_"}], "]"}], ":=", 
  RowBox[{"N", "[", 
   RowBox[{"Log", "[", 
    RowBox[{"10", ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"ao", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "^", 
         RowBox[{"(", 
          RowBox[{"13", "/", "2"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"13", "/", "2"}], ")"}], "*", "0.5", "*", 
         RowBox[{"mass", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "*", "t"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"2", "/", "13"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"13d06367-a226-4918-afc2-2811e8f2d3ba"],

Cell[TextData[{
 "Set the value of ",
 StyleBox["tmax", "Input"],
 ", the maximum time in the past that we are considering."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e4b766bc-1ced-4e08-9eae-d119743e866e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{"4.6", "*", 
    RowBox[{"10", "^", 
     RowBox[{"(", "12", ")"}]}]}]}], ";"}]], "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"1ddab03e-a073-4da6-b670-35e7e8a5823f"],

Cell[TextData[{
 "Derive a list of values of ",
 StyleBox["t", "Input"],
 " and ",
 StyleBox["a", "Input"],
 " for each satellite."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"54af8130-ce11-4345-bf98-b7a6270931ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"evol1", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"tmax", "-", "t"}], ")"}], "/", "tmax"}], ",", 
       RowBox[{"a", "[", 
        RowBox[{"1", ",", "t"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax", ",", 
       RowBox[{"0.01", "*", 
        RowBox[{"10", "^", 
         RowBox[{"(", "12", ")"}]}]}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[7]:=",ExpressionUUID->"1392a319-4008-4375-8f91-a6ec46975bc9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"evol2", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"tmax", "-", "t"}], ")"}], "/", "tmax"}], ",", 
       RowBox[{"a", "[", 
        RowBox[{"2", ",", "t"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax", ",", 
       RowBox[{"0.01", "*", 
        RowBox[{"10", "^", 
         RowBox[{"(", "12", ")"}]}]}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[8]:=",ExpressionUUID->"76950076-21cb-42e7-bb32-df500a5ce273"],

Cell[BoxData[
 RowBox[{
  RowBox[{"evol3", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"tmax", "-", "t"}], ")"}], "/", "tmax"}], ",", 
       RowBox[{"a", "[", 
        RowBox[{"3", ",", "t"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax", ",", 
       RowBox[{"0.01", "*", 
        RowBox[{"10", "^", 
         RowBox[{"(", "12", ")"}]}]}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[9]:=",ExpressionUUID->"4195b785-1de3-4479-b55e-3b4dbd8dbb6c"],

Cell["Derive a plot of these values for each satellite.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"626cf600-ab04-4c86-ba65-8762d94a7c52"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"evol1", ",", 
    RowBox[{"Joined", "->", "True"}], ",", " ", 
    RowBox[{"DisplayFunction", "->", "Identity"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.811584700387936*^9, 3.811584701121729*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"05aa674b-8757-4642-97e2-b30c0a51d438"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9l3dY02cXhhGos6gMUWtRUbFuHKAFAk8EAdl7byQMJyAqjronrrpHrbui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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 5.053457289449305},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1.}, {5.053457289449305, 5.1132746924643495`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8115847314824963`*^9, 3.811584775294632*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"43250ac2-c963-4f59-bfa8-23832f4425c4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p2", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"evol2", ",", " ", 
    RowBox[{"Joined", "->", "True"}], ",", " ", 
    RowBox[{"DisplayFunction", "->", "Identity"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8115847035953693`*^9, 3.811584704194841*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"cf2432e5-80d4-4843-9f47-5cae216b0985"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1l3lczWkbhyuVUmlwDsYSkUFCvaSs32OJxhqSNclkl2KQbcIkGmTJNtFY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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 5.074557278442487},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1.}, {5.074557278442487, 5.281487887940081}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811584731547978*^9, 3.8115847753773003`*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"cd87aa3f-7364-42bb-9f24-1a6602a38bd0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p3", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"evol3", ",", " ", 
    RowBox[{"Joined", "->", "True"}], ",", " ", 
    RowBox[{"DisplayFunction", "->", "Identity"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.81158471147608*^9, 3.811584712208126*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"acb9e85d-1388-4813-a482-f683faf6f85e"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9l3dczfsfx8vIKMKV0VUSEWXENYuXGdde5VpRiGvkCiEqK+uXkZWRrAq3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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 5.417771153689133},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1.}, {5.417771153689133, 5.424881636631066}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811584731630293*^9, 3.811584775444108*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"4b3a93db-9919-4060-a5c6-0458d53cdd8e"]
}, Open  ]],

Cell["Show all these plots together.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"be00a9ff-7a20-47e3-a519-1fc41b09b50c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bigplot", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"p1", ",", "p2", ",", "p3", ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5.0", ",", "5.5"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"DisplayFunction", "->", "$DisplayFunction"}], ",", " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", 
    RowBox[{"AspectRatio", "->", "0.8"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.811584761774129*^9},
 CellLabel->"In[13]:=",ExpressionUUID->"bf9cef1f-9a0e-4a85-a349-1ba19203ceaf"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9l3dY02cXhhGos6gMUWtRUbFuHKAFAk8EAdl7byQMJyAqjronrrpHrbui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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1l3lczWkbhyuVUmlwDsYSkUFCvaSs32OJxhqSNclkl2KQbcIkGmTJNtFY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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9l3dczfsfx8vIKMKV0VUSEWXENYuXGdde5VpRiGvkCiEqK+uXkZWRrAq3
8x0nRBmVCu2lvTudTqeNe8mI36fvfbzP+cfj+Sif8xnv9+v5rp/T9sUbWmlp
aSVra2m1/PvfpxFbtJssuj80mOy1evGXEfUNeOOo692FcXNE4AfHwgYU5NQW
6TE+0OtzzfmEBix08B/TgfG33b8rY542IKOh99m2jN0zrxf/E9wA3eMbVNqM
2WI5ZpcacMfYCz9CDSbvPTM53f5IA6bInf2+Mm5Z7fiOBpwe36fhE2O3luXW
NMAy9KbtR8b/Bo99oZ7H9mPw/kYD451tToUZ2jSg2aHLvzWM2eaEOUMa4Hai
eU4V4x2Rwx4c6MX24/P0TgXjxj6H7nA6DXjkPOVLKePt0gbr8bzLlQVFjFt2
p6+oh4/386A8xttGt+ywHtGR/LcsxrUt24usx7dwl0UZjLdIC9Yjx+V7cApj
9byWFevxPnfZ9wTGm0Ki2RbrUfnh4KI3jFXtu7Ml67HwyZ7gGMbO0qce8SY2
3yIZt5zWb2k9qgenLHjOeH0/3eVvp9ZjXvLQwKeMFZ7Sg+BE25VNjxg7tRy3
bz2sku3myhmXjm81Y2WnepQYG9/iGLPFJvl8q8PAfx9+fMCYPQa7wDpcm91z
ZjBjabWcOqT2nnXtDmNpudd1sF9tWxfAeGWngP4LH9UhSr/b5OuM8ze3HLgO
Ny1CzvsxZpvrEXquDodDuiovMM5tuT7POnw+OWPsOcb2R1pOXIcz0bYnfRhn
SRusQ/pcg4ITjFt2t/v3OswdKLf0ZiyVy1j2+7MMPQ8xlrZnVgcjfmGqB+N0
acE6HF201MSd8cJHLSvWYd5Qsx1ujFO7mrMt1uKHdUy0K+P50gPXwnjvsG7b
GSdJn1qMKnR22sK45bTNEbWIdtoaupFxy+sOe1CLBTpotZ6xVH5+tVgdXbxo
LWPpuN612H5mzu1VjGfeannhWuhs8m78g/FrqUFqETjLB3aMZ0gXWIvXQ9ae
WcQ4tuV5J9Witr120TzG0nKWtbhY5GIxm3G0VNC1sL77YJ8t4/8OzL5/qfzN
VMZSOX+uwe4abwMwlq5PWYMfToPWWTN+IRVgDVwfXxLHMraRNliDmUVpzaMY
P2tpX6EGn9/lzh7BeEJLuQQwvsz5WTKWtudTg5dGCyrMGY+VFqxB1LoXI8wY
s2ZjK7L11zUd6MdYag97tn5PrXgjxtJzzKiBfN+77oaMR0mfGph6717bg3HL
adf3q0GH3xQh3RhbSQ1Xg6yDRp87MxalB6nG5w0Dpuoy/u+41Sgo+uzTjjGn
0/LC1Wgo98tpzdhSapBqBGxvY6rFWGq3sGos8Zy49bvcYLL0vIHV2NthWlgT
Y2m589XYo2ug9S9jc6mgq/HE8+Hv7xnfkw5cjVurjS/UMR7YUs6rq3H1jl2h
mrF0fXOq0W7WcrNKxv2lAqzG/FmDXcoZ35E2WI3MG3FhxYyl9u3BzjN12M98
xlK5tKmG8ch1M3MYS9v7oMa9DevPZjIOkBZU42OOVU4qY6OWuEpVw/FIonES
Y///GhgLnayc3zKWniNEjT7b13GxjK9KHzVMAx3/iWIsxfNxNV58s7B+wViK
g91qzPrr1aFwxlL5rVfD6PuAt48ZS8ddrMaFq0s6hzLuLgWgGq2nzV/KM74g
NYgasR+6X/ubcTfpAtWwvHuvJJix9Ly6apyZr2N2l7G03JcqTGkYsfkmYynu
VVW47DVIuM5YipesKpR+UX/0YyyVc0wV/vpj77iLjKXrC62C36WMA+cYn5IK
sAp3QpqifBh3kDZYBcXF6jYnGZ+QAr8KwXPuz/JmLJXL5iqMSbDyOcRY2t7y
KpR3PJ7qwVjSx8wqvG93v5s7YymuRldBeHbRzo2x1B79q+BsMu+KK2PpObpW
YcWI9HwXxv/5sgrZShOjLXLypQrG1jZrNjL+IflShT1D+t9eJydfqjCIzypf
IydfqrA9asmAVXLypQrnV97Y8IecfKlCxr7Q4KVy8qUKLgYXVAvl5EsV7pvD
fJ6cfKnCMy5s0+9y8qUKqoAv92fIyZcqbPrUTj1FTr5UYT9fZj5JTr5U4Y/o
Y5smyMmXKkwY/PneGDn5shIrS0eqRsrJl5V4Xzp+4HA5+bISv5npbbCQky8r
seLeg7uD5OTLSvg5divvLydfVsJkvq2JiZx8WYnBG2c49JGTLytRHqzv30tO
vqyER7ugvO5y8mUlLI607dlVTr6shGF3q6Wd5OTLSrg/GuTbQU6+rISbgzq5
LeMyyZeVsNFz69hKTr5UoulJsu0PkXypRObKxsNfRfKlEp/fF738JJIvlfDZ
dfnrB5F8qcSzot5jGkTypRIhgzbtqBHJl0p4zT0kU4nkSyVW2W5QKRgvkwpQ
iT/1u5uWiuRLJV7fPr2qUCRfKnHpc/rlXJF8qcSnjmVp70TypRK62REd00Xy
pRIfFq+ZniySL5V4uz/FI14kX1YgZHb7J3Ei+bICYeF6jdGMkyVfVqBtTIH5
S5F8WQH52t2OESL5sgKZPnlXw0TyZQWOTmmfESqSLyuQv1e7oyCSLytQYxk3
JUQkX1YgedmSffdE8mUFLn4MEe+K5MsKLPmaorrJeJoUWBUwdH5u7C+SLyvw
Y8Quuysi+bICenaf/ndRJF8qYJc09dU5kXypQOW55U0+IvlSgWT/CcNOiuRL
BXpUK9d5i+RL9nPXlVcPieRLBb6OuJ7iwThcKhgF7hsHtXYXyZcKlIzeN85N
JF8qEPxXz22uIvlSgTbxXrddRPKlAs3jQrM2i+RLBS5H8B02iuRLBdJn7p64
TiRfKvAwv+2ONSL5shzW29YGrmQ8XBJcOTZ/OZqzTCRflgP7dnZcKpIvyxFR
aTFxoUi+LEeWNb99rki+LMdZ16+3Z4nky3IojnZ5N10kX5Yjfmtj2yki+bIc
EwdcGztRJF+WY0xQpz/HMw6SAqYcMvXsa6NF8mU5LtQsSrQSyZds/UDT70NF
8iX7fv0XlkNE8mU5Tpn1Wz1QJF+W4XXp/NOmIvmyDKOtbV8Yi+TLMrwd1q7O
UCRflmHrY98+PRn/Kj1wGbrEK+f8IpIvy3B7Xev9+iL5sgx6XtUPdEXyZRls
DK7nthPJl2XobWLQro1IvizD2at/jNYSyZdlOLp/w7rvAvmyDGWR1r5NAvmy
DCfXFrz8h7GvJKQyrF82vbZRIF+WYkmAW+86gXxZCpvhrrZqgXxZih+tx+5U
CuTLUnj0iLtZJpAvS+G3tk9SkUC+LMWQQpumPIF8WQqDIwMHZAvky1KMXpC3
IEMgX5Zi/QS7/SkC+bIUXpOuBScI5MtSrLG7n/5aIF+WonCv1/dXAvmyFMl3
+g6KFMiXpeiYfGLRM4F8WYpN7yP2PxHo78kSPOsQFvRQIB+WIFffPVUQyH8l
ONus8yVEIN+V4GHSKtP7AvmtBAZ79s8JFMhnJTj8yWnXLYH8VYKE6b/c8BfI
V8WIWOkTd0UgPxXDaHRK3UWBfFSMqIRcA1+B/FOMrT1kE08L5JtiqLvO2nBS
IL8UQ/uJzMdboL+/iuH+M+/hIYH8UQRDZWq+h0C+KEKQ4xltd4H8UIQSFwNz
N4F8UITTOhvmuwqU/0XYZuqxy0WgvC/CtOerr20WKN+LkJSsE+UsUJ4X4u3C
vUongf7eKcTHSaEd1wiU14XQPf9o+EqB8rkQidO8li4TKI8LUTuv274lAuVv
IQb/ve3GAoHythDjF/tGzxEoXwuQCQ/lTIHytADcVqsO0wXKzwJ4ZHCWkwX6
+6IAnzZ/WGAjUD4WIHH4T9dxAuUh+/+G7y79JlD+FWCB2Y6nIwTKu3w4/J6d
bylQvuXjxMHWzeYC5Vk+PGObjM0Eyq98VHcOm9xPoLzKx97l1k5GAs3z+ci4
ceJIb4HyKB+3s24EGgiUP/nw+eoe11WgvMnDRB2Tyk4C5Useln3w0ekoUJ7k
4fDT6IE6AuVHHhwWv7RtJVBe5OFc+GHnHzzlQx7CVZ2PfeVpfs7D/mynoE88
9X8uXL08Yz/w1O+5QKGjop6n/s7FwUq9VjU89XMu0vy8TFQ89W8uEtThkxQ8
9Wsu2mU/W1XCU3/mwtTe272Ap/k1B6HrelzJ4WlezcG8JpfHmTzNpzk41els
RipP82gOvvu7NSTyNH/mYPwtM723PM2bOUjr4m8ey9N8mYOlVXnTo3iaJ7Nh
b1Ky9jlP82M2NoSGHHjK07yYjU5XcOURT/NhNgoTrj0UeZoHs+Ew/UWKjKf5
LxvGP4LV93ma97IR9H5ZmyCe5rssHOiVZnybp3kuC4O36o+/wdP8loXfKg2W
XOVpXstCv4OKrZd4ms+ysHvU3mO+PM1jWQj9knnzNE/zVxZWJH16epKneSsL
9YGl6d48zVfvUHfAt/oQT/PUO+TM69Dak6f56R3Mu8761Z2neekdVkfNG+XG
03z0Dg1LDee48jQPvcOqt5yTC0/zzzs2/7Z338zTvJOJ21aDfZ15mm8yscmw
630nnuaZTCjfRL504Gl+ycTpUaOzVvA0r2Qi3X5HjT1P80kmzCx2aS/haR7J
xNcHE3su4Gn+yEBkUrLlHJ7mjQxU+AyYOpOn+SID2Yopy6bxNE9kQDvRbCt4
mh8ykGGddtCap3khA/LhUy6N5Wk+yEDHW3sfjOJpHkjH1GNuL4bz5P90vCqY
kG7Bk+/T0Xg1rmIQT35Px7CIHk39efJ5OspHD9M14cnf6dimo2fchydfp8PK
TBzRiyc/p+HM/wyndefJx2koHznHrgtP/k2DT/epG/V48m0a1IN/7m3Pk1/T
sHjr4VNtePJpGvpnJV7X4smfaQhbXSD7zpEv0+D0U3zRxJEfU+HxcG7KPxz5
MBUOO/niRo78l4qV47LraznyXQpiv8X8qOLIbymoD9vTWcmRz1Jgvu69URlH
/kpB3JcRQ4s48lUyuu4aY5PHkZ+SsTJRe04WRz5KRkPT+eXpHPknCb0/qTcm
c+SbJPR/ruMWz5FfkmA3XX0kjiOfJKHpuK9vNEf+SMTigz8DXnDki0T8PXCU
LJwjPyRi6i7L8Mcc+SABa5xq4uQc5X8Cpldvz+A4yvsEDG8bUfyAo3xPgKMs
vjqIozyPR++8gE+3OcrveFw6Or5VAEd5HQ/9+1c7XeMon+MRaxPZ6zJHefwW
ddZ/9z/PUf6+xauAFcPOcJS3b+HhkDbuFEf5+gaLdulOO8ZRnr6BW57uvMMc
5ecbGB1Pt/fkKC/f4IDbqrXuHOXja8Tckv3pxlEevobpz2hXV47y7zXiT/nv
d+Eo7+JQaWNzdDNH+RaHoM63fZw5yrM4jPqScNGJo/yKQ/i/4f4OHOVVLByb
twWu4CifYrGkgyrEnqM8isWTbmYPF3OUP7GQdzOPmM9R3sTAuVVj1GyO8iUG
3/IPvLHlKE9icPZSSvJUjvLjFWZYKDMncZQXrzDpUlTeBI7y4RUuJa0tGcNR
HrzCloS4ipEc9X808o43qIdx1O/R+NZcVD+Eo/6ORq2Z78eBHPVzFGKb2jeZ
ctS/Ubi6fcZ3Y476NQqHj9hq/cpRf0bh4lC9Nj01/RgJhfPldr9o+i8SB82V
HfU1/fYSnluaOulq+usl6szTurTT9NML5C/f+ktrTf88h93nJIOfMuqX59j0
9X3PbzLqj2cwWVXQ+7OM+uEZjhuc/PWjjOo/AkF9v/VpkFG9R+DQTivjGhnV
dzhMO1r2VcmonsNxprC6r0JG9fsUbxXbTEpkVK9PkN7rsUmBjOrzCfhdUSY5
MqrHMKxuPGuSKaP6C0Ph0f4mqTKqt8ewsNjfN1FG9fUYMwovG7+RUT09wkBf
N6MYGdXPI7yZatgnUkb18hCm1YcMn8moPkIx/CDX64mM6iEUimb/Hg9l9P5y
jFq1sLsgo/eW45eLb7qGyOh9RewJaKV/T0bvKWLBLm29uzJ6PwE+nWPb35TR
e/Ho4zy77XUZvY8MdTsvavtp3iMEtSPuNJ/X3P/faHN555czmvt+AGP/9v+e
0tzvffS3cWw8prnPe/jm4lFzWHN/wfAZurrSU3NfQYj4S6vMXXM/gdhitbHA
TXMfd+C5yTfLVXP+28jp7JXqojnvLdgZjYjfrDnfTWT5BL5y1pzHH2PtC585
afZ/DfauOY8cNPu9Ar38S9wKzf4uY/SxnsH2mv1cRPD2VQGLNd/viwln11+e
r/m+s4gpGn5mtmb9U+ix9KW3rWa9Y+hQo+8xVfP/D2Hr9QG7Jml+3x1dHb5v
nqD5+Q68tvBzHKNhRyxv/mfZSBn5UkvrSqLB/GGM/w9fxZNp
       "]]}}, {{}, {}}}},
  AspectRatio->0.8,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 5.053457289449305},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1}, {5., 5.5}},
  PlotRangeClipping->True,
  PlotRangePadding->None,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811584731641513*^9, 3.8115847754521008`*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"7673af4b-404b-4cc6-ad50-ffd3a8be11cb"]
}, Open  ]],

Cell[TextData[{
 "Now we need to find the times when resonances have been encountered.  \
Define a function ",
 StyleBox["FindRes", "Input"],
 " that will take the list of ",
 StyleBox["t", "Input"],
 " and ",
 StyleBox["a", "Input"],
 " values for two satellites and look for occurences of the ratio ",
 StyleBox["ratio", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"868849fa-7e9b-4ace-b70c-68252a9e0ce3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FindRes", "[", 
   RowBox[{"d1_", ",", "d2_", ",", " ", "ratio_"}], "]"}], ":=", "\n", "\t", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\n", "\t\t", 
    RowBox[{
     RowBox[{"time", " ", "=", " ", 
      RowBox[{
       RowBox[{"Transpose", "[", "d1", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\t\t", 
     RowBox[{"data1", " ", "=", " ", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Transpose", "[", "d1", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ")"}]}]}], ";", "\n", "\t\t", 
     RowBox[{"data2", " ", "=", " ", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Transpose", "[", "d2", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], ")"}]}]}], ";", "\n", "\t\t", 
     RowBox[{"mm", " ", "=", " ", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"data1", "/", "data2"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}], "-", "ratio"}], "]"}]}], ";", 
     "\n", "\t\t", 
     RowBox[{"mindif", " ", "=", " ", 
      RowBox[{"Min", "[", "mm", "]"}]}], ";", "\n", "\t\t", 
     RowBox[{"tres", " ", "=", " ", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"time", ",", "mm"}], "}"}], "]"}], ",", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "==", "mindif"}], ")"}], 
           "&"}]}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\t\t", 
     RowBox[{"pos", " ", "=", " ", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"Position", "[", 
         RowBox[{"time", ",", " ", "tres"}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\t\t", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"d1", "[", 
        RowBox[{"[", "pos", "]"}], "]"}], ",", 
       RowBox[{"d2", "[", 
        RowBox[{"[", "pos", "]"}], "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellLabel->"In[14]:=",ExpressionUUID->"be53cffd-4d17-44bd-8bcd-127c25751ea6"],

Cell["Search for specific first- and second-order resonances.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"bdaea833-5b9c-410c-9f82-8db562a18030"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l1", "=", 
  RowBox[{"FindRes", "[", 
   RowBox[{"evol1", ",", "evol2", ",", " ", 
    RowBox[{"N", "[", 
     RowBox[{"3", "/", "4"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[15]:=",ExpressionUUID->"4d6d55fa-7d03-43f4-85c0-dae42158cb97"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.08478260869565217`", ",", "5.0637714747712135`"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"0.08478260869565217`", ",", "5.146923158456683`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.81158473166982*^9, 3.8115847754947557`*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"4f695281-71e3-423e-a635-d357803367b4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l2", "=", 
  RowBox[{"FindRes", "[", 
   RowBox[{"evol1", ",", "evol2", ",", " ", 
    RowBox[{"N", "[", 
     RowBox[{"2", "/", "3"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[16]:=",ExpressionUUID->"c4572fa6-8ff9-4870-b4d2-8678171174a7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.2152173913043478`", ",", "5.073483921212127`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2152173913043478`", ",", "5.190695791184856`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8115847317183533`*^9, 3.8115847755396843`*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"8a9bb8cd-8921-4c45-bc1e-97ae7fc25478"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l3", "=", 
  RowBox[{"FindRes", "[", 
   RowBox[{"evol1", ",", "evol3", ",", 
    RowBox[{"N", "[", 
     RowBox[{"1", "/", "3"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[17]:=",ExpressionUUID->"f2901f62-f8d8-46bd-8036-cc4c02d8454c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.808695652173913`", ",", "5.105534538809246`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.808695652173913`", ",", "5.423644411484918`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8115847322308693`*^9, 3.811584775594799*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"62c4417b-8768-4262-945f-2aa0131026d6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l4", "=", 
  RowBox[{"FindRes", "[", 
   RowBox[{"evol2", ",", "evol3", ",", 
    RowBox[{"N", "[", 
     RowBox[{"1", "/", "2"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[18]:=",ExpressionUUID->"20909adb-27a8-462d-a3bc-b33cc668eee6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.3652173913043478`", ",", "5.220094869736118`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.3652173913043478`", ",", "5.420684995457173`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8115847324069033`*^9, 3.811584775639513*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"41e9907e-b343-4b9f-a9e3-03f637c1fce0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l5", "=", 
  RowBox[{"FindRes", "[", 
   RowBox[{"evol2", ",", "evol3", ",", 
    RowBox[{"N", "[", 
     RowBox[{"3", "/", "5"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[19]:=",ExpressionUUID->"c5431a6b-758b-4376-9dad-5037607f8c5e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9239130434782609`", ",", "5.276492338422427`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9239130434782609`", ",", "5.424392298892487`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.811584732459977*^9, 3.811584775645265*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"957c33cb-1b76-4906-b3ae-16c3d646112a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lines", "=", 
  RowBox[{"Graphics", "[", 
   RowBox[{"Map", "[", 
    RowBox[{"Line", ",", 
     RowBox[{"{", 
      RowBox[{"l1", ",", "l2", ",", "l3", ",", "l4", ",", "l5"}], "}"}]}], 
    "]"}], "]"}]}]], "Input",
 CellLabel->"In[20]:=",ExpressionUUID->"f1e94636-6c50-4baa-9c57-1b61c110e890"],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{0.08478260869565217, 5.0637714747712135`}, {0.08478260869565217, 
    5.146923158456683}}], 
   LineBox[{{0.2152173913043478, 5.073483921212127}, {0.2152173913043478, 
    5.190695791184856}}], 
   LineBox[{{0.808695652173913, 5.105534538809246}, {0.808695652173913, 
    5.423644411484918}}], 
   LineBox[{{0.3652173913043478, 5.220094869736118}, {0.3652173913043478, 
    5.420684995457173}}], 
   LineBox[{{0.9239130434782609, 5.276492338422427}, {0.9239130434782609, 
    5.424392298892487}}]}]], "Output",
 CellChangeTimes->{3.811584732465147*^9, 3.8115847756907883`*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"b8ba89c2-9657-4a4e-9a99-a7e7f6c1f3fc"]
}, Open  ]],

Cell["\<\
Create a graphic object consisting of lines for each of these resonances.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b827ad0b-dad7-4e80-a0c6-c8d6ba99c2a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bigplot", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"p1", ",", "p2", ",", "p3", ",", "lines", ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5.0", ",", "5.5"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"DisplayFunction", "->", "$DisplayFunction"}], ",", " ", 
    RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", 
    RowBox[{"AspectRatio", "->", "0.8"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.8115847555893784`*^9},
 CellLabel->"In[21]:=",ExpressionUUID->"7c4270e8-d694-438e-958d-b1dca55ae2b3"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9l3dY02cXhhGos6gMUWtRUbFuHKAFAk8EAdl7byQMJyAqjronrrpHrbui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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1l3lczWkbhyuVUmlwDsYSkUFCvaSs32OJxhqSNclkl2KQbcIkGmTJNtFY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       "]]}}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9l3dczfsfx8vIKMKV0VUSEWXENYuXGdde5VpRiGvkCiEqK+uXkZWRrAq3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       "]]}}, {{}, {}}}, {
    LineBox[{{0.08478260869565217, 5.0637714747712135`}, {0.08478260869565217,
      5.146923158456683}}], 
    LineBox[{{0.2152173913043478, 5.073483921212127}, {0.2152173913043478, 
     5.190695791184856}}], 
    LineBox[{{0.808695652173913, 5.105534538809246}, {0.808695652173913, 
     5.423644411484918}}], 
    LineBox[{{0.3652173913043478, 5.220094869736118}, {0.3652173913043478, 
     5.420684995457173}}], 
    LineBox[{{0.9239130434782609, 5.276492338422427}, {0.9239130434782609, 
     5.424392298892487}}]}},
  AspectRatio->0.8,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 5.053457289449305},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1}, {5., 5.5}},
  PlotRangeClipping->True,
  PlotRangePadding->None,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811584732475341*^9, 3.811584775697016*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"b30d9da5-2e77-4e64-a152-30707ba1b399"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{924, 622},
WindowMargins->{{16, Automatic}, {53, Automatic}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"09d599fb-29aa-41e6-9e35-5e9cdd6af279"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 111, 0, 67, "Section",ExpressionUUID->"c86ab8d0-f2e0-430f-9eba-c802d258ac8b"],
Cell[672, 22, 254, 6, 49, "Text",ExpressionUUID->"5ef0332b-04a8-4df1-9519-392471bcc80c"],
Cell[CellGroupData[{
Cell[951, 32, 290, 7, 30, "Input",ExpressionUUID->"9cd32df4-35a3-4f90-82ef-3c9bd9cbf0cf"],
Cell[1244, 41, 254, 5, 37, "Output",ExpressionUUID->"39b54702-10fc-45a3-aac8-cfeedec13a18"]
}, Open  ]],
Cell[1513, 49, 213, 6, 53, "Text",ExpressionUUID->"06f74281-b329-47ba-9944-1f17de509e22"],
Cell[CellGroupData[{
Cell[1751, 59, 205, 4, 30, "Input",ExpressionUUID->"dc874c31-e029-4d71-ac34-d1e4554bc82d"],
Cell[1959, 65, 241, 4, 34, "Output",ExpressionUUID->"9459b40b-1a4f-4610-8135-b9c3c6513e5f"]
}, Open  ]],
Cell[2215, 72, 399, 9, 76, "Text",ExpressionUUID->"eee9ea91-17bd-4986-ae7f-296106f08e33"],
Cell[2617, 83, 646, 20, 30, "Input",ExpressionUUID->"ebc077b4-c741-4487-af41-8394963c72c0"],
Cell[3266, 105, 217, 6, 53, "Text",ExpressionUUID->"291108fe-4c8a-4f81-8756-076b6841fdf1"],
Cell[CellGroupData[{
Cell[3508, 115, 390, 11, 30, "Input",ExpressionUUID->"49a8c7e5-7d98-4582-b4fd-8dda33d4545f"],
Cell[3901, 128, 789, 20, 76, "Output",ExpressionUUID->"add7ea5d-f370-4e1d-bff6-767b30866502"]
}, Open  ]],
Cell[4705, 151, 396, 14, 53, "Text",ExpressionUUID->"aa48dd1d-92d3-42f7-84b0-3ac9f01df4df"],
Cell[5104, 167, 744, 22, 30, "Input",ExpressionUUID->"13d06367-a226-4918-afc2-2811e8f2d3ba"],
Cell[5851, 191, 246, 7, 53, "Text",ExpressionUUID->"e4b766bc-1ced-4e08-9eae-d119743e866e"],
Cell[6100, 200, 227, 6, 30, "Input",ExpressionUUID->"1ddab03e-a073-4da6-b670-35e7e8a5823f"],
Cell[6330, 208, 253, 9, 53, "Text",ExpressionUUID->"54af8130-ce11-4345-bf98-b7a6270931ea"],
Cell[6586, 219, 593, 17, 30, "Input",ExpressionUUID->"1392a319-4008-4375-8f91-a6ec46975bc9"],
Cell[7182, 238, 593, 17, 30, "Input",ExpressionUUID->"76950076-21cb-42e7-bb32-df500a5ce273"],
Cell[7778, 257, 593, 17, 30, "Input",ExpressionUUID->"4195b785-1de3-4479-b55e-3b4dbd8dbb6c"],
Cell[8374, 276, 175, 3, 53, "Text",ExpressionUUID->"626cf600-ab04-4c86-ba65-8762d94a7c52"],
Cell[CellGroupData[{
Cell[8574, 283, 354, 7, 30, "Input",ExpressionUUID->"05aa674b-8757-4642-97e2-b30c0a51d438"],
Cell[8931, 292, 7833, 143, 236, "Output",ExpressionUUID->"43250ac2-c963-4f59-bfa8-23832f4425c4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16801, 440, 361, 7, 30, "Input",ExpressionUUID->"cf2432e5-80d4-4843-9f47-5cae216b0985"],
Cell[17165, 449, 7998, 146, 236, "Output",ExpressionUUID->"cd87aa3f-7364-42bb-9f24-1a6602a38bd0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25200, 600, 358, 7, 30, "Input",ExpressionUUID->"acb9e85d-1388-4813-a482-f683faf6f85e"],
Cell[25561, 609, 7723, 141, 233, "Output",ExpressionUUID->"4b3a93db-9919-4060-a5c6-0458d53cdd8e"]
}, Open  ]],
Cell[33299, 753, 156, 3, 53, "Text",ExpressionUUID->"be00a9ff-7a20-47e3-a519-1fc41b09b50c"],
Cell[CellGroupData[{
Cell[33480, 760, 679, 16, 52, "Input",ExpressionUUID->"bf9cef1f-9a0e-4a85-a349-1ba19203ceaf"],
Cell[34162, 778, 21070, 360, 309, "Output",ExpressionUUID->"7673af4b-404b-4cc6-ad50-ffd3a8be11cb"]
}, Open  ]],
Cell[55247, 1141, 459, 14, 76, "Text",ExpressionUUID->"868849fa-7e9b-4ace-b70c-68252a9e0ce3"],
Cell[55709, 1157, 2300, 62, 220, "Input",ExpressionUUID->"be53cffd-4d17-44bd-8bcd-127c25751ea6"],
Cell[58012, 1221, 181, 3, 53, "Text",ExpressionUUID->"bdaea833-5b9c-410c-9f82-8db562a18030"],
Cell[CellGroupData[{
Cell[58218, 1228, 266, 6, 30, "Input",ExpressionUUID->"4d6d55fa-7d03-43f4-85c0-dae42158cb97"],
Cell[58487, 1236, 395, 10, 34, "Output",ExpressionUUID->"4f695281-71e3-423e-a635-d357803367b4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58919, 1251, 266, 6, 30, "Input",ExpressionUUID->"c4572fa6-8ff9-4870-b4d2-8678171174a7"],
Cell[59188, 1259, 391, 9, 34, "Output",ExpressionUUID->"8a9bb8cd-8921-4c45-bc1e-97ae7fc25478"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59616, 1273, 261, 6, 30, "Input",ExpressionUUID->"f2901f62-f8d8-46bd-8036-cc4c02d8454c"],
Cell[59880, 1281, 387, 9, 34, "Output",ExpressionUUID->"62c4417b-8768-4262-945f-2aa0131026d6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60304, 1295, 261, 6, 30, "Input",ExpressionUUID->"20909adb-27a8-462d-a3bc-b33cc668eee6"],
Cell[60568, 1303, 389, 9, 34, "Output",ExpressionUUID->"41e9907e-b343-4b9f-a9e3-03f637c1fce0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60994, 1317, 261, 6, 30, "Input",ExpressionUUID->"c5431a6b-758b-4376-9dad-5037607f8c5e"],
Cell[61258, 1325, 387, 9, 34, "Output",ExpressionUUID->"957c33cb-1b76-4906-b3ae-16c3d646112a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61682, 1339, 319, 8, 30, "Input",ExpressionUUID->"f1e94636-6c50-4baa-9c57-1b61c110e890"],
Cell[62004, 1349, 697, 13, 180, "Output",ExpressionUUID->"b8ba89c2-9657-4a4e-9a99-a7e7f6c1f3fc"]
}, Open  ]],
Cell[62716, 1365, 207, 5, 53, "Text",ExpressionUUID->"b827ad0b-dad7-4e80-a0c6-c8d6ba99c2a4"],
Cell[CellGroupData[{
Cell[62948, 1374, 695, 16, 52, "Input",ExpressionUUID->"7c4270e8-d694-438e-958d-b1dca55ae2b3"],
Cell[63646, 1392, 21592, 370, 309, "Output",ExpressionUUID->"b30d9da5-2e77-4e64-a152-30707ba1b399"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

